======================
Vivarium Documentation
======================

Vivarium is a framework for building complex simulations using standard
`scientific Python <https://www.scipy.org/>`_ tools.

.. toctree::
   :maxdepth: 2

   installation
   tutorials/index
   concepts/index
   api_reference/index
   glossary
